@@ -4,6 +4,7 @@ import getpass
 import os
 import subprocess
 
+from pathlib import Path
 from typing import TYPE_CHECKING
 from typing import Any
 from typing import Callable
@@ -87,7 +88,7 @@ class Question:
         """
         self._write_prompt(io)
 
-        if not self._autocomplete_values or not self._has_stty_available():
+        if not (self._autocomplete_values and self._has_stty_available()):
             ret: str | None = None
 
             if self.is_hidden():
@@ -117,7 +118,7 @@ class Question:
         """
         Outputs an error message.
         """
-        io.write_error_line(f"<error>{str(error)}</error>")
+        io.write_error_line(f"<error>{error!s}</error>")
 
     def _autocomplete(self, io: IO) -> str:
         """
@@ -264,7 +265,7 @@ class Question:
         return ret.strip()
 
     def _has_stty_available(self) -> bool:
-        with open(os.devnull, "w") as devnull:
+        with Path(os.devnull).open("w") as devnull:
             try:
                 exit_code = subprocess.call(["stty"], stdout=devnull, stderr=devnull)
             except Exception:
